@@ -18,11 +18,9 @@ class Electrons(Method):
     """A container for methods pertaining to electrons."""
 
     def __init__(self, data, progress=None, loglevel=logging.INFO, logname="Log"):
-
+        super().__init__(data, progress, loglevel, logname)
         self.required_attrs = ('atomnos','charge','coreelectrons','homos')
 
-        super(Electrons, self).__init__(data, progress, loglevel, logname)
-
     def __str__(self):
         """Returns a string representation of the object."""
         return "Electrons"
