@@ -17,17 +17,15 @@ from cclib.method.population import Population
 class LPA(Population):
     """The Löwdin population analysis"""
     def __init__(self, *args):
-
-        # Call the __init__ method of the superclass.
-        super(LPA, self).__init__(logname="LPA", *args)
+        super().__init__(logname="LPA", *args)
 
     def __str__(self):
         """Return a string representation of the object."""
-        return "LPA of %s" % (self.data)
+        return f"LPA of {self.data}"
 
     def __repr__(self):
         """Return a representation of the object."""
-        return 'LPA("%s")' % (self.data)
+        return f'LPA("{self.data}")'
 
     def calculate(self, indices=None, x=0.5, fupdate=0.05):
         """Perform a calculation of Löwdin population analysis.
@@ -90,7 +88,7 @@ class LPA(Population):
         if self.progress:
             self.progress.update(nstep, "Done")
 
-        retval = super(LPA, self).partition(indices)
+        retval = super().partition(indices)
 
         if not retval:
             self.logger.error("Error in partitioning results")
