@@ -13,6 +13,8 @@ import re
 import datetime
 import numpy
 
+from packaging.version import parse as parse_version, Version
+
 from cclib.parser import logfileparser
 from cclib.parser import utils
 
@@ -21,17 +23,15 @@ class QChem(logfileparser.Logfile):
     """A Q-Chem log file."""
 
     def __init__(self, *args, **kwargs):
-
-        # Call the __init__ method of the superclass
-        super(QChem, self).__init__(logname="QChem", *args, **kwargs)
+        super().__init__(logname="QChem", *args, **kwargs)
 
     def __str__(self):
         """Return a string representation of the object."""
-        return "QChem log file %s" % (self.filename)
+        return f"QChem log file {self.filename}"
 
     def __repr__(self):
         """Return a representation of the object."""
-        return 'QChem("%s")' % (self.filename)
+        return f'QChem("{self.filename}")'
 
     def normalisesym(self, label):
         """Q-Chem does not require normalizing symmetry labels."""
@@ -76,8 +76,9 @@ class QChem(logfileparser.Logfile):
         self.ncolsblock = 6
 
         # By default, when asked to print orbitals via
-        # `scf_print`/`scf_final_print` and/or `print_orbitals`,
-        # Q-Chem will print all occupieds and the first 5 virtuals.
+        # `scf_print`/`scf_final_print` and/or `print_orbitals`, Q-Chem will
+        # print all occupieds and the first 5 virtuals for versions prior to
+        # 5.2.
         #
         # When the number is set for `print_orbitals`, that section of
         # the output will display (NOcc + that many virtual) MOs, but
@@ -90,7 +91,6 @@ class QChem(logfileparser.Logfile):
         # NBasis)!
         self.norbdisp_alpha = self.norbdisp_beta = 5
         self.norbdisp_alpha_aonames = self.norbdisp_beta_aonames = 5
-        self.norbdisp_set = False
 
         self.alpha_mo_coefficient_headers = (
             'RESTRICTED (RHF) MOLECULAR ORBITAL COEFFICIENTS',
@@ -116,6 +116,7 @@ class QChem(logfileparser.Logfile):
         ]
 
     def after_parsing(self):
+        super(QChem, self).after_parsing()
 
         # If parsing a fragment job, each of the geometries appended to
         # `atomcoords` may be of different lengths, which will prevent
@@ -161,8 +162,8 @@ class QChem(logfileparser.Logfile):
                         # principal quantum number (1S, 2P, 3D, 4F,
                         # ...).
                         bfcounts[bfname] = angmom.index(bfname[0])
-                    newbfname = '{}{}'.format(bfcounts[bfname], bfname)
-                    self.aonames[bfindex] = '_'.join([atomname, newbfname])
+                    newbfname = f"{bfcounts[bfname]}{bfname}"
+                    self.aonames[bfindex] = "_".join([atomname, newbfname])
 
         # Assign the number of core electrons replaced by ECPs.
         if hasattr(self, 'user_input') and self.user_input.get('rem') is not None:
@@ -327,7 +328,7 @@ cannot be determined. Rerun without `$molecule read`."""
                         if row[2] != '':
                             name = self.atommap.get(row[1] + str(row[2]))
                         else:
-                            name = self.atommap.get(row[1] + '1')
+                            name = self.atommap.get(f"{row[1]}1")
                         # For l > 1, there is a space between l and
                         # m_l when using spherical functions.
                         shell = row[2 + offset]
@@ -447,15 +448,24 @@ cannot be determined. Rerun without `$molecule read`."""
                 package_version = groups[0]
                 self.metadata["package_version"] = package_version
                 self.metadata["legacy_package_version"] = package_version
+                self.set_attribute("parsed_svn_revision", False)
         # Avoid "Last SVN revision" entry.
         if "SVN revision" in line and "Last" not in line:
             svn_revision = line.split()[3]
             line = next(inputfile)
             svn_branch = line.split()[3].replace("/", "_")
-            if "package_version" in self.metadata:
-                self.metadata["package_version"] = "{}dev+{}-{}".format(
-                    self.metadata["package_version"], svn_branch, svn_revision
-                )
+            if (
+                "package_version" in self.metadata
+                and hasattr(self, "parsed_svn_revision")
+                and not self.parsed_svn_revision
+            ):
+                self.metadata[
+                    "package_version"
+                ] = f"{self.metadata['package_version']}dev+{svn_branch}-{svn_revision}"
+                parsed_version = parse_version(self.metadata["package_version"])
+                assert isinstance(parsed_version, Version)
+                self.set_attribute("package_version", parsed_version)
+                self.set_attribute("parsed_svn_revision", True)
 
         # Disable/enable parsing for fragment sections.
         if any(message in line for message in self.fragment_section_headers):
@@ -526,7 +536,6 @@ cannot be determined. Rerun without `$molecule read`."""
                                     norbdisp_aonames = int(option)
                                     self.norbdisp_alpha_aonames = norbdisp_aonames
                                     self.norbdisp_beta_aonames = norbdisp_aonames
-                                    self.norbdisp_set = True
 
                     if line.strip().lower() == '$ecp':
 
@@ -594,6 +603,15 @@ cannot be determined. Rerun without `$molecule read`."""
 
                     line = next(inputfile).lower()
 
+            # Point group symmetry.
+            if 'Molecular Point Group' in line:
+                point_group_full = line.split()[3].lower()
+                self.metadata['symmetry_detected'] = point_group_full
+                line = next(inputfile)
+                if 'Largest Abelian Subgroup' in line:
+                    point_group_abelian = line.split()[3].lower()
+                    self.metadata['symmetry_used'] = point_group_abelian
+
             # Parse the basis set name
             if 'Requested basis set' in line:
                 self.metadata["basis_set"] = line.split()[-1]
@@ -709,7 +727,7 @@ cannot be determined. Rerun without `$molecule read`."""
                 elif 'Bohr' in line:
                     convertor = lambda x: utils.convertor(x, 'bohr', 'Angstrom')
                 else:
-                    raise ValueError("Unknown units in coordinate header: {}".format(line))
+                    raise ValueError(f"Unknown units in coordinate header: {line}")
                 self.skip_lines(inputfile, ['cols', 'dashes'])
                 atomelements = []
                 atomcoords = []
@@ -772,6 +790,21 @@ cannot be determined. Rerun without `$molecule read`."""
                     self.norbdisp_beta = min(self.norbdisp_beta, self.nbasis)
                     self.norbdisp_beta_aonames = min(self.norbdisp_beta_aonames, self.nbasis)
 
+            # Finally, versions of Q-Chem greater than 5.1.2 print all MOs in
+            # the "Final <Spin> MO Coefficients" blocks, but *not* the
+            # "MOLECULAR ORBITAL COEFFICIENTS" blocks.
+            if hasattr(self, "package_version"):
+                pv = self.package_version
+                if pv.major >= 5 and pv.minor > 1:
+                    norbdisp = None
+                    if hasattr(self, "nmo"):
+                        norbdisp = self.nmo
+                    elif hasattr(self, "nbasis"):
+                        norbdisp = self.nbasis
+                    if norbdisp is not None:
+                        self.norbdisp_alpha = norbdisp
+                        self.norbdisp_beta = norbdisp
+
             # Check for whether or not we're peforming an
             # (un)restricted calculation.
             if 'calculation will be' in line:
@@ -834,7 +867,9 @@ cannot be determined. Rerun without `$molecule read`."""
                         line = next(inputfile)
                     # Is this the end of the file for some reason?
                     except StopIteration:
-                        self.logger.warning('File terminated before end of last SCF! Last error: {}'.format(error))
+                        self.logger.warning(
+                            f"File terminated before end of last SCF! Last error: {error}"
+                        )
                         break
 
                     # We've converged, but still need the last iteration.
@@ -1126,7 +1161,7 @@ cannot be determined. Rerun without `$molecule read`."""
                             elif ttype == 'Y':
                                 sec.append([end, start, contrib])
                             else:
-                                raise ValueError('Unknown transition type: %s' % ttype)
+                                raise ValueError(f"Unknown transition type: {ttype}")
                             line = next(inputfile)
                         etsecs.append(sec)
 
@@ -1653,8 +1688,3 @@ cannot be determined. Rerun without `$molecule read`."""
                 self.metadata['cpu_time'].append(cpu_td)
             except:
                 pass
-
-        # TODO:
-        # 'nocoeffs'
-        # 'nooccnos'
-        # 'vibanharms'
